@@ -26,8 +26,7 @@ from docker import APIClient
 from docker.errors import APIError
 from docker.types import DeviceRequest, LogConfig, Mount, Ulimit
 
-from airflow.exceptions import AirflowException, AirflowSkipException
-from airflow.models import TaskInstance
+from airflow.providers.common.compat.sdk import AirflowException, AirflowSkipException
 from airflow.providers.docker.exceptions import DockerContainerFailedException
 from airflow.providers.docker.operators.docker import DockerOperator, fetch_logs
 
@@ -98,7 +97,7 @@ def test_hook_usage(docker_hook_patcher, docker_conn_id, tls_params: dict):
 
 
 @pytest.mark.parametrize(
-    "env_str, expected",
+    ("env_str", "expected"),
     [
         pytest.param("FOO=BAR\nSPAM=EGG", {"FOO": "BAR", "SPAM": "EGG"}, id="parsable-string"),
         pytest.param("", {}, id="empty-string"),
@@ -150,7 +149,7 @@ class TestDockerOperator:
         self.client_mock.pull.return_value = {"status": "pull log"}
         self.client_mock.wait.return_value = {"StatusCode": 0}
         self.client_mock.create_host_config.return_value = mock.Mock()
-        self.log_messages = ["container log  😁   ", b"byte string container log"]
+        self.log_messages = ["container log  😁   \n", b"byte string container log\n"]
         self.client_mock.attach.return_value = self.log_messages
 
         # If logs() is called with tail then only return the last value, otherwise return the whole log.
@@ -532,7 +531,7 @@ class TestDockerOperator:
             print_exception_mock.assert_not_called()
 
     @pytest.mark.parametrize(
-        "kwargs, actual_exit_code, expected_exc",
+        ("kwargs", "actual_exit_code", "expected_exc"),
         [
             ({}, 0, None),
             ({}, 100, AirflowException),
@@ -567,7 +566,7 @@ class TestDockerOperator:
 
     def test_execute_container_fails(self):
         failed_msg = {"StatusCode": 1}
-        log_line = ["unicode container log 😁   ", b"byte string container log"]
+        log_line = ["unicode container log 😁   \n", b"byte string container log\n"]
         expected_message = "Docker container failed: {failed_msg}"
         self.client_mock.attach.return_value = log_line
         self.client_mock.wait.return_value = failed_msg
@@ -580,7 +579,7 @@ class TestDockerOperator:
         assert str(raised_exception.value) == expected_message.format(
             failed_msg=failed_msg,
         )
-        assert raised_exception.value.logs == [log_line[0].strip(), log_line[1].decode("utf-8")]
+        assert raised_exception.value.logs == [log_line[0].rstrip(), log_line[1].decode("utf-8").rstrip()]
 
     def test_auto_remove_container_fails(self):
         self.client_mock.wait.return_value = {"StatusCode": 1}
@@ -623,9 +622,9 @@ class TestDockerOperator:
         assert no_xcom_push_result is None
 
     def test_execute_xcom_behavior_bytes(self):
-        self.log_messages = [b"container log 1 ", b"container log 2"]
+        self.log_messages = [b"container log 1 \n", b"container log 2\n"]
         self.client_mock.pull.return_value = [b'{"status":"pull log"}']
-        self.client_mock.attach.return_value = iter([b"container log 1 ", b"container log 2"])
+        self.client_mock.attach.return_value = iter([b"container log 1 \n", b"container log 2\n"])
         # Make sure the logs side effect is updated after the change
         self.client_mock.attach.side_effect = (
             lambda **kwargs: iter(self.log_messages[-kwargs["tail"] :])
@@ -759,12 +758,12 @@ class TestDockerOperator:
         assert operator.docker_url == "unix://var/run/docker.sock"
 
     @pytest.mark.parametrize(
-        "log_lines, expected_lines",
+        ("log_lines", "expected_lines"),
         [
             pytest.param(
                 [
-                    "return self.main(*args, **kwargs)",
-                    "                 ^^^^^^^^^^^^^^^^",
+                    "return self.main(*args, **kwargs)\n",
+                    "                 ^^^^^^^^^^^^^^^^\n",
                 ],
                 [
                     "return self.main(*args, **kwargs)",
@@ -774,13 +773,25 @@ class TestDockerOperator:
             ),
             pytest.param(
                 [
-                    "   ^^^^^^^^^^^^^^^^   ",
+                    "   ^^^^^^^^^^^^^^^^   \n",
                 ],
                 [
                     "   ^^^^^^^^^^^^^^^^",
                 ],
                 id="should-remove-trailing-spaces",
             ),
+            # Test case for issue #58911: Docker stream may chunks lines mid-way
+            pytest.param(
+                [
+                    b"    rv = self.invoke(ctx)\n         ^^^",
+                    b"^^^^^^^^^^^^^\n",
+                ],
+                [
+                    "    rv = self.invoke(ctx)",
+                    "         ^^^^^^^^^^^^^^^^",
+                ],
+                id="should-handle-mid-line-chunk-splits",
+            ),
         ],
     )
     @mock.patch("logging.Logger")
@@ -810,7 +821,7 @@ class TestDockerOperator:
             operator.execute({})
 
         dr = dag_maker.create_dagrun()
-        ti = TaskInstance(task=operator, run_id=dr.run_id)
+        ti = dr.task_instances[0]
         rendered = ti.render_templates()
         assert rendered.container_name == f"python_{dr.dag_id}"
         assert rendered.mounts[0]["Target"] == f"/{ti.run_id}"
